pub struct ExecOutput {
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
pub exit_code: i32,
pub truncated: bool,
}Expand description
Output from an executed command.
Fields
stdout: Vec<u8>Captured stdout bytes.
stderr: Vec<u8>Captured stderr bytes.
exit_code: i32Process exit code.
truncated: boolWhether either captured stream exceeded its bound and was truncated.
Defaults to false when reading responses from older guest binaries.